Project
=======

.. autoclass:: nanohubremote.project.Project
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

.. autoclass:: nanohubremote.project.ProjectFilesFS
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

The Project classes provide filesystem access to nanoHUB project files.
